@@ -5,17 +5,17 @@ from PySide.QtCore import *
 from PySide.QtGui import *
 
 # Some global variables
-FceuGuiVersion = "0.0.1-3"
+FceuGuiVersion = "0.0.1-4"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
 FceuGui_CfgFile = Home + '/.config/fceu-gui/fceu-gui.cfg'
+LastPlayed_File = Home + '/.config/fceu-gui/last_played.txt'
 P1buttons = ""
 P2buttons = ""
-P1joybuttons = ""
-P2joybuttons = ""
+#P1joybuttons = ""
+#P2joybuttons = ""
 BiosPath = ""
-RomrcPath = ""
 RomPath = ""
 ExecPath = ""
 
@@ -70,7 +70,7 @@ class Ui_MainWindow(QMainWindow):
 	backgroundLabel.setAlignment(Qt.AlignCenter | Qt.AlignLeft)
       	self.setCentralWidget(backgroundLabel)
 	# Get Gametitles from rom_path
-	ListCmd = "cd '" + self.gui_opts["rom_path"] + "';ls -1 *.zip *.ZIP *.NES *.nes 2>/dev/null|sort -f" 
+	ListCmd = "cd '" + self.gui_opts["rom_path"] + "';ls -1 *.zip *.ZIP *.NES *.nes *.nsf *.NSF 2>/dev/null|sort -f" 
 	fin,fout = os.popen4(ListCmd)
 	romList = fout.read()
 	fin.close()
@@ -87,6 +87,13 @@ class Ui_MainWindow(QMainWindow):
 	 min-width: 6em; \
 	 }" )
 	self.combo.setGeometry(QRect(20, 180, 750, 60))
+	# Read last started file
+	try:
+		playedFile = open(LastPlayed_File,"r")
+	except:
+		last_game = "dummy"
+	else:
+		last_game = playedFile.readlines()
 	maxLength=63
 	for Game in romList:
 		space=""
@@ -95,6 +102,9 @@ class Ui_MainWindow(QMainWindow):
 			space=space+" "
        		self.combo.addItem(space+Game)
 	self.GameFile=[[t] for t in romList if t]
+	# Set last file as current
+	if last_game[0] in romList:
+		self.combo.setCurrentIndex(romList.index(last_game[0]))
 
 	# Define menubar
 	aboutAction = QAction( '&About', self)
@@ -151,13 +161,17 @@ class Ui_MainWindow(QMainWindow):
 			ALL_OPTS = ALL_OPTS + "-efxfs 0 "
 	else:
         	if self.gui_opts["fs"] == "false":
-			ALL_OPTS = ALL_OPTS + "-efx 2 "
+			ALL_OPTS = ALL_OPTS + "-efxfs 2 "
 		else:
 			ALL_OPTS = ALL_OPTS + "-efxfs 2 "
 	ALL_OPTS = ALL_OPTS + "-bpp " + self.gui_opts["bpp"] + " "
 
 	if not (self.gameFile == "No roms found" ):
-		# we can't do multiple commands in startDetached
+		# Write as last played game
+		playedFile = open(LastPlayed_File,"w")
+		playedFile.write(self.gameFile)
+		playedFile.close()
+		# Start emulator with parameters
 		print self.gui_opts["exec_path"] + "/fceu "+ALL_OPTS+ " " + '"' + self.gui_opts["rom_path"] + "/" + self.gameFile +  '"'
 		QProcess.startDetached(self.gui_opts["exec_path"] + "/fceu "+ALL_OPTS+ " " + '"' + self.gui_opts["rom_path"] + "/" + self.gameFile + '"' )
 
